==> haskell-cookie-0.4.5-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cookie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cookie
version:              0.4.5
visibility:           public
id:                   cookie-0.4.5-7vzD1BW7e5L2KNeTKf8wPs
key:                  cookie-0.4.5-7vzD1BW7e5L2KNeTKf8wPs
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://github.com/snoyberg/cookie
synopsis:             HTTP cookie parsing and rendering
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/cookie>.

category:             Web, Yesod
abi:                  5dbbbbdcf5cff864edfac1dcacbeab58
exposed:              True
exposed-modules:      Web.Cookie
import-dirs:          /usr/lib/ghc-8.8.3/site-local/cookie-0.4.5
library-dirs:         /usr/lib/ghc-8.8.3/site-local/cookie-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/cookie-0.4.5
hs-libraries:         HScookie-0.4.5-7vzD1BW7e5L2KNeTKf8wPs
depends:
    base-4.13.0.0 bytestring-0.10.10.0
    data-default-class-0.1.2.0-3WblArvKItDIiwkDl9AciG deepseq-1.4.4.0
    text-1.2.4.0 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-cookie/html/cookie.haddock
haddock-html:         /usr/share/doc/haskell-cookie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cookie-0.4.5-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cookie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cookie
version:              0.4.5
visibility:           public
id:                   cookie-0.4.5-6wiVaNkJelwF683ZPKo0AJ
key:                  cookie-0.4.5-6wiVaNkJelwF683ZPKo0AJ
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://github.com/snoyberg/cookie
synopsis:             HTTP cookie parsing and rendering
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/cookie>.

category:             Web, Yesod
abi:                  4fe3df5202452081b82f0acb3f52409b
exposed:              True
exposed-modules:      Web.Cookie
import-dirs:          /usr/lib/ghc-8.10.1/site-local/cookie-0.4.5
library-dirs:         /usr/lib/ghc-8.10.1/site-local/cookie-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/cookie-0.4.5
hs-libraries:         HScookie-0.4.5-6wiVaNkJelwF683ZPKo0AJ
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    data-default-class-0.1.2.0-AZTcEqCsR4uCdCN1ROsSjZ deepseq-1.4.4.0
    text-1.2.3.2 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-cookie/html/cookie.haddock
haddock-html:         /usr/share/doc/haskell-cookie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
